Plot the inclusion frequency of the most common 2-covariate combinations.
xp.inc.prob.comb.2(
bootgam.obj = NULL,
boot.type = NULL,
main = NULL,
col = "#6495ED",
xlb = NULL,
ylb = "Covariate combination",
...
)A lattice plot object will be returned.
The bootgam or bootscm object.
Either "bootgam" or "bootscm". Default is NULL, which means the user will be asked to make a choice.
Plot title
Color used for plot.
Label for x-axis.
Label for y-axis.
Additional plotting parameters.
Ron Keizer