Inclusion stability plot
A plot of the inclusion frequency of covariates vs bootgam/bootscm iteration number. This plot can be used to evaluate whether sufficient iterations have been performed.
xp.inc.stab.cov(
bootgam.obj = NULL,
boot.type = NULL,
main = NULL,
normalize = TRUE,
split.plots = FALSE,
xlb = "Bootstrap replicate number",
ylb = "Difference of estimate with final",
...
)A lattice plot object is returned.
The bootgam or bootscm object.
Either "bootgam" or "bootscm". Default is NULL, which means the user will be asked to make a choice.
Plot title
Should the plot be normalized?
Should the plots be split?
The label for the x-axis.
The label for the y-axis.
Additional plotting parameters
Ron Keizer
Other bootgam:
xp.daic.npar.plot(),
xp.dofv.npar.plot(),
xp.inc.cond.stab.cov(),
xp.inc.ind.cond.stab.cov(),
xp.incl.index.cov(),
xp.incl.index.cov.ind()
Other bootscm:
bootscm.import(),
xp.daic.npar.plot(),
xp.dofv.npar.plot(),
xp.inc.cond.stab.cov(),
xp.inc.ind.cond.stab.cov(),
xp.incl.index.cov(),
xp.incl.index.cov.ind()