xpose.plot.qq function.
Most of the arguments take their default values from xpose.data object but this
can be overridden by supplying them as argument to xpose.plot.qq.xpose.panel.qq(x, object,
pch = object@Prefs@Graph.prefs$pch,
col = object@Prefs@Graph.prefs$col,
cex = object@Prefs@Graph.prefs$cex,
abllty = object@Prefs@Graph.prefs$abllty,
abllwd = object@Prefs@Graph.prefs$abllwd,
ablcol = object@Prefs@Graph.prefs$ablcol,
grid = object@Prefs@Graph.prefs$grid,
...)xpose.plot.qq,
qqmath,
panel.qqmathline,
xpose.data-class